/* SLPv2 model for Omnet++
 * Copyright (C) 2004  Manuel Urueña <muruenya@it.uc3m.es>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#include "Service.h"

Register_Class(Service);

Service::Service(const char* t, const char* u, const char* attrs,
		 int life, simtime_t now) 
  : cObject(u), type(t), url(u), attributes(attrs)
{
  lifetime = life;
  timestamp = now;
}

Service::Service(const char* t, const char* u, int life, simtime_t now)
  : cObject(u), type(t), url(u), attributes("")
{
  lifetime = life;
  timestamp = now;
}

const char* Service::getType()
{
  return type.c_str();
}

const char* Service::getURL()
{
  return url.c_str();
}

const char* Service::getAttributes()
{
  return attributes.c_str();
}

void Service::setAttributes ( const char* attrs )
{
  attributes = attrs;
}

int Service::getLifetime()
{
  return lifetime;
}

void Service::setLifetime(int life)
{
  lifetime = life;
}

simtime_t Service::getAge ( simtime_t now )
{
  simtime_t age = now - timestamp;
  if (age > timestamp) {
    age = timestamp;
  }

  return age;
}

simtime_t Service::getTTL ( simtime_t now )
{
  simtime_t age = now - timestamp;
  simtime_t ttl = lifetime - age;
  if (ttl < 0) {
    ttl = 0;
  }

  return ttl;
}

bool Service::hasType(const char* t)
{
  return (type == t);
}

bool Service::hasType(string& t)
{
  return (type == t);
}

bool Service::hasExpired ( simtime_t now )
{
  if (lifetime == -1) {
    return false;
  }

  simtime_t age = now - timestamp;
  return (age >= lifetime);
}

void Service::refresh ( simtime_t now )
{
  timestamp = now;
}


// cObject stuff
//
Service::Service ( const char * name ) : cObject(name)
{
  // Does nothing
}

Service::Service ( const Service& other ) : cObject(other.name())
{
  operator=(other);
}

Service::~Service()
{
}

cObject *Service::dup() const
{
  return new Service(*this);
}

Service& Service::operator= ( const Service& other )
{
  if (&other == this) {
    return *this;
  }

  cObject::operator=(other);

  type = other.type;
  url = other.url;
  attributes = other.attributes;
  lifetime = other.lifetime;
  timestamp = other.timestamp;

  return *this;
}

void Service::foreach ( ForeachFunc f )
{
  f(this, false);
}

void Service::info ( char *buf )
{
  sprintf(buf+strlen(buf), "%s (?/%d) %s", 
	  url.c_str(), lifetime, attributes.c_str());
}

void Service::writeContents ( ostream& os )
{
  os << "service:" << url.c_str() << " (?/" << lifetime << ") "
     << attributes.c_str();
}
