/* SLPv2 model for Omnet++
 * Copyright (C) 2004  Manuel Urueña <muruenya@it.uc3m.es>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#ifndef SERVICE_H_
#define SERVICE_H_

#include <omnetpp.h>
#include <string>
using std::string;

class Service : public cObject
{
 protected:
  string type;
  string url;
  string attributes;
  int lifetime;
  simtime_t timestamp;
 
 public:
  Service(const char* type, const char* url, const char* attrs, 
	  int lifetime, simtime_t now);

  Service(const char* type, const char* url, int lifetime, 
	  simtime_t now);

  virtual const char* getType();
  virtual const char* getURL();
  virtual const char* getAttributes();
  virtual        void setAttributes(const char* attrs);
  virtual         int getLifetime();
  virtual        void setLifetime(int lifetime);
  virtual   simtime_t getAge(simtime_t now);
  virtual   simtime_t getTTL(simtime_t now);
  virtual        bool hasType(const char* type);
  virtual        bool hasType(string& type);
  virtual        bool hasExpired(simtime_t now);
  virtual        void refresh(simtime_t now);


  //cObject stuff
  Service(const char *name=NULL);
  Service(const Service& other);
  virtual ~Service();
  virtual cObject *dup() const;
  Service& operator=(const Service& other);
  virtual void foreach(ForeachFunc f);
  virtual void info (char * buf);
  virtual void writeContents(std::ostream& os);
};

#endif
