/* SLPv2 model for Omnet++
 * Copyright (C) 2004  Manuel Urueña <muruenya@it.uc3m.es>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#include "Sockaddr_in.h"

Register_Class(Sockaddr_in);

Sockaddr_in::Sockaddr_in
(const char* name, const char* port, const char* addr) 
  : cObject(name), sin_addr(addr), sin_port(port) {}

const char* Sockaddr_in::getPort()
{
  return sin_port.c_str();
}

const char* Sockaddr_in::getAddress()
{
  return sin_addr.c_str();
}

// cObject stuff
//
Sockaddr_in::Sockaddr_in ( const char* name ) : cObject(name) {}

Sockaddr_in::Sockaddr_in ( const Sockaddr_in& other ) 
  : cObject(other.name())
{
  operator=(other);
}

Sockaddr_in::~Sockaddr_in() {}


cObject *Sockaddr_in::dup() const
{
  return new Sockaddr_in(*this);
}

Sockaddr_in& Sockaddr_in::operator= ( const Sockaddr_in& other )
{
  if (&other == this) {
    return *this;
  }

  cObject::operator=(other);

  sin_port = other.sin_port;
  sin_addr = other.sin_addr;

  return *this;
}

void Sockaddr_in::foreach ( ForeachFunc f )
{
  f(this, false);
}

void Sockaddr_in::info ( char *buf )
{
  sprintf(buf+strlen(buf), "%s: %s:%s (Sockaddr_in)", name(),
	  sin_addr.c_str(), sin_port.c_str());
}

void Sockaddr_in::writeContents ( ostream& os )
{
  os << sin_addr.c_str() << ":" << sin_port.c_str();
}
